@@ -313,7 +313,7 @@ def cellpose_torch(a_imgscaled, i_diameter, s_model_type, b_gpu=True):
         sys.exit(f'Error @ mplexable.segment.cellpose_torch : function called with b_gpu set {b_gpu},\nthough torch.cuda.is_available ({torch.cuda.is_available()}) could not detect any gpu.')
 
     # run model
-    model = models.Cellpose(model_type=s_model_type, gpu=b_gpu, device=None, torch=True)
+    model = models.Cellpose(gpu=b_gpu, model_type=s_model_type, net_avg=False, device=None)
 
     if s_model_type == 'nuclei':
         li_channel = [0,0]
